intelmq.bots.experts.aggregate package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.aggregate package

## Submodules

## intelmq.bots.experts.aggregate.expert module

Aggregate Expert

SPDX-FileCopyrightText: 2021 Intelmq Team <intelmq-team@cert.at> SPDX-License-Identifier: AGPL-3.0-or-later

class intelmq.bots.experts.aggregate.expert.AggregateExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`, `intelmq.lib.mixins.cache.CacheMixin`

  Aggregation expert bot

  cleanup()
  fields: str = 'classification.type, classification.identifier'
  init()
  process()
  redis_cache_db: int = 8
  threshold: int = 10
  timespan: str = '1 hour'

intelmq.bots.experts.aggregate.expert.BOT

  alias of `intelmq.bots.experts.aggregate.expert.AggregateExpertBot`

## Module contents